```
Usage: vcd org delete [OPTIONS] <name>

Options:
  -r, --recursive  removes the Org and any objects it contains that are in a
                   state that normally allows removal
  -f, --force      pass this option along with --recursive to remove an Org
                   and any objects it contains, regardless of their state
  -h, --help       Show this message and exit.

```
